import { TextProps } from '../Text/Text';
import { TypeColor } from '../types';
export type TypeButtonSize = 'x1' | 'x2' | 'x3';
/**
 * Button component with a fill and outline style with a variety of colours
 * for different purposes.
 */
export interface ButtonProps extends TextProps {
    /** Retains the Button in its active state */
    active?: boolean;
    /** Background color when active */
    backgroundColorActive?: TypeColor;
    /** Background color when hovered */
    backgroundColorHover?: TypeColor;
    /** border color when active */
    borderColorActive?: TypeColor;
    /** border color when hover */
    borderColorHover?: TypeColor;
    /**
     * Color that is applied to the button to indicate the type of action
     *
     * @default "accent"
     */
    color?: 'accent' | 'negative' | 'positive';
    /** A styled disabled state that disables all interactions */
    disabled?: boolean;
    /** text color when active */
    textColorActive?: TypeColor;
    /** border color when hover */
    textColorHover?: TypeColor;
    /**
     * React Router "to" prop, when applied the Component given to Button
     * is that of a RouterLink (from React Router DOM). Otherwise an
     * anchor tag is used.
     */
    to?: string;
    /**
     * Changes the visual priority of the button
     *
     * @default "secondary"
     */
    variant?: 'primary' | 'secondary' | 'tertiary';
}
export declare const Button: import('react').ForwardRefExoticComponent<ButtonProps & import('react').RefAttributes<any>>;
