import { LucideIcon } from 'lucide-react';
import { PropsWithChildren } from 'react';
import { TransitionBoxProps } from '../TransitionBox/TransitionBox';
export interface ConfigMenuProps extends TransitionBoxProps {
    config: MenuConfig;
}
export type MenuConfig = MenuConfigEntry[];
export type MenuConfigEntry = MenuConfigEntryDivider | MenuConfigEntryBoolean | MenuConfigEntryNumber | MenuConfigEntryOneOf<any> | MenuConfigEntryManyOf<any> | MenuConfigEntryAction | MenuConfigEntryActions;
export type MenuConfigEntryWithValue = MenuConfigEntryBoolean | MenuConfigEntryNumber | MenuConfigEntryOneOf<any> | MenuConfigEntryManyOf<any>;
export type MenuConfigEntryDivider = {
    type: 'divider';
};
export type MenuConfigEntryBase = {
    label: string;
    icon: LucideIcon;
    disabled?: boolean;
};
export type MenuConfigEntryBoolean = MenuConfigEntryBase & {
    type: 'boolean';
    value: boolean;
    labelTrue: string;
    labelFalse: string;
    onChange: (value: boolean) => void;
};
export type MenuConfigEntryNumber = MenuConfigEntryBase & {
    type: 'number';
    value: number;
    min: number;
    max: number;
    step: number;
    formatter?: (value: number) => string;
    onChange: (value: number) => void;
};
export type MenuConfigEntryOneOf<T> = MenuConfigEntryBase & {
    type: 'oneOf';
    value: T;
    options: T[];
    formatter?: (value: T) => string;
    onChange: (value: T) => void;
};
export type MenuConfigEntryManyOf<T> = MenuConfigEntryBase & {
    type: 'manyOf';
    value: T[];
    options: T[];
    formatter?: (value: T) => string;
    onChange: (value: T[]) => void;
};
export type MenuConfigEntryAction = MenuConfigEntryBase & {
    type: 'action';
    onAction: () => void;
};
export type MenuConfigEntryActions = MenuConfigEntryBase & {
    type: 'actions';
    actions: {
        label: string;
        onAction: () => void;
    }[];
};
export declare const ConfigMenu: ({ config, title, ...rest }: PropsWithChildren<ConfigMenuProps>) => import("react/jsx-runtime").JSX.Element;
