import { SetStateAction, PropsWithChildren } from 'react';
import { FormValidateError } from './useForm';
export type FormState<T, E> = {
    error: FormValidateError<T, E>;
    hasError: boolean;
    hasSubmitted: boolean;
    getIsDirty: (field?: keyof T) => boolean;
    state: T;
    setDirty: (field: keyof T) => void;
    setError: (error: FormValidateError<T, E> | null) => void;
    setState: (cb: SetStateAction<T>) => void;
    setSubmitted: () => void;
    reset: () => void;
};
export type FormContextProps<T, E> = {
    form: FormState<T, E>;
    getError: (field: string) => string | undefined;
    registerField: (field: string, element: HTMLElement) => () => void;
};
/**
 * A context provider that communicates a field-by-field error/validation
 * pattern. Must be provided with a form from the useForm hook.
 */
export interface FormProviderProps {
    /**
     * Form state provided by the useForm hook. Used to enable
     * validations and error handling feedback in the UI components
     * through context.
     */
    form: FormState<any, any>;
    /**
     * Only validate fields that have been dirtied.
     */
    validateOnlyDirty?: boolean;
    /**
     * Only validate fields once the form has been submitted
     */
    validateOnlySubmitted?: boolean;
    /**
     *  Validates only one field at a time, in order as they appear
     * from the top of the screen.
     */
    validateOnlyOneAtATime?: boolean;
}
export declare const FormProvider: ({ form, validateOnlyDirty, validateOnlySubmitted, validateOnlyOneAtATime, ...rest }: PropsWithChildren<FormProviderProps>) => import("react/jsx-runtime").JSX.Element;
