import { PointerEvent } from 'react';
import { TypeAnimation } from '../Appear/Appear';
import { BoxProps } from '../Box/Box';
import { TypeColor } from '../types';
/**
 * The containing component for all the other Modal components.
 * This component contains the unpadded dialog box as well as
 * an overlay, animations and behaviour to disable body scroll when
 * it is visible.
 */
export interface ModalProps extends Omit<BoxProps, 'size'> {
    /**
     * Animation for the Modal window. See Appear component.
     *
     * @default "Fade"
     */
    animation?: TypeAnimation;
    /**
     * Extends the initial height of the modal to
     * be the full height of the viewport
     */
    fullscreen?: boolean;
    /**
     * A flag to ignore visibility management by ModalManager
     */
    ignoreModalManager?: boolean;
    /**
     * Sets the background color of the overlay that sits
     * under the modal and on top of the main UI.
     *
     * @default "overlay"
     */
    overlayBackgroundColor?: TypeColor;
    /**
     * Flag to enable/disable clicking on the overlay to close the modal.
     *
     * @default true
     */
    overlayBackgroundCloseOnClick?: boolean;
    /**
     * An optional callback that when provided will be
     * called when clicking on the visible overlay area
     * and when clicking on the cross icon inside the
     * ModalHeader.
     */
    onClose?: (event: PointerEvent<HTMLElement>) => void;
    /**
     * Called once the modal has finished animating out and
     * has been removed from the DOM.
     */
    onCloseAnimationComplete?: () => void;
    /**
     * Unrenders the modal when not visible
     *
     * @defaults true
     */
    unrender?: boolean;
    /**
     * The visible state of the modal. When the visibility
     * is set to false, the content will be removed from the
     * DOM.
     */
    visible: boolean;
}
export declare const Modal: import('react').ForwardRefExoticComponent<ModalProps & import('react').RefAttributes<any>>;
