import { useInteractions, Placement, UseRoleProps, UseFloatingReturn, ReferenceType } from '@floating-ui/react';
export type UsePlacementTrigger = 'hover' | 'click';
export declare const ARROW_HEIGHT = 12;
export declare const ARROW_WIDTH = 24;
export interface UsePlacementOptions {
    /**
     * The initial open state of the content
     */
    initialOpen?: boolean;
    /**
     * The directional placement of the content
     */
    placement?: Placement;
    /**
     * The controlled open state of the content
     */
    open?: boolean;
    /**
     * Set the controlled open state of the content
     */
    onOpenChange?: (isOpen: boolean) => void;
    /**
     * The role of the content
     */
    role?: UseRoleProps['role'];
    /**
     * Whether to set the content width as the reference width
     */
    setContentWidthAsReferenceWidth?: boolean;
    /**
     * The trigger on the reference
     */
    trigger?: UsePlacementTrigger;
}
export interface UsePlacementResult extends UseFloatingReturn<ReferenceType>, ReturnType<typeof useInteractions> {
    /**
     *
     */
    arrowRef: (ref: SVGSVGElement | null) => void;
    /**
     * Whether the tooltip is open.
     * @default false
     */
    open: boolean;
    /**
     * Set whether the tooltip is open.
     */
    setOpen: (open: boolean) => void;
}
export default function usePlacement({ initialOpen, placement, open: controlledOpen, onOpenChange: setControlledOpen, role: roleString, setContentWidthAsReferenceWidth, trigger, }: UsePlacementOptions): UsePlacementResult;
